==> skrooge_0.2.5.orig.tar.gz: skrooge-0.2.5/skgbankmodeler/skgsuboperationobject.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSUBOPERATIONOBJECT_H
#define SKGSUBOPERATIONOBJECT_H
/** @file
 * This file is part of Skrooge and defines classes SKGSubOperationObject.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */

#include "skgobjectbase.h"

class SKGOperationObject;
class SKGCategoryObject;

/**
 * This class manages suboperation object
 */
class KDE_EXPORT SKGSubOperationObject : public SKGObjectBase
{
        Q_OBJECT;

public:
        /**
         * Constructor
         * @param iDocument the document containing the object
         * @param iID the identifier in @p iTable of the object
         */
        explicit SKGSubOperationObject(const SKGDocument* iDocument=NULL, int iID=0);

        /**
         * Copy constructor
         * @param iObject the object to copy
         */
        SKGSubOperationObject(const SKGSubOperationObject& iObject);

        /**
         * Copy constructor
         * @param iObject the object to copy
         */
        SKGSubOperationObject(const SKGObjectBase& iObject);

        /**
         * Operator affectation
         * @param iObject the object to copy
         */
        virtual const SKGSubOperationObject& operator= (const SKGObjectBase &iObject);

        /**
         * Destructor
         */
        virtual ~SKGSubOperationObject();
        /**
         * Set the comment of suboperation
         * @param iComment the comment
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setComment(const QString& iComment);

        /**
         * Get the comment of this suboperation
         * @return the comment
         */
        virtual QString getComment() const;

        /**
         * Get the parent operation
         * @param oOperation the parent operation
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError getParentOperation(SKGOperationObject& oOperation) const;

        /**
         * Set the parent operation
         * @param iOperation the parent operation
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError setParentOperation(const SKGOperationObject& iOperation);

        /**
         * Set the category
         * @param iCategory the category
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setCategory(const SKGCategoryObject& iCategory);

        /**
         * Get the category
         * @param oCategory the category
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError getCategory(SKGCategoryObject& oCategory) const;

        /**
         * Set the quantity of the suboperation
         * @param iValue the value
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setQuantity(double iValue);

        /**
         * Get the quantity of the suboperation
         * @return the value
         */
        virtual double getQuantity() const;

};

#endif

==> skrooge_0.2.9.orig.tar.gz: skrooge-0.2.9/skgbankmodeler/skgsuboperationobject.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSUBOPERATIONOBJECT_H
#define SKGSUBOPERATIONOBJECT_H
/** @file
 * This file is part of Skrooge and defines classes SKGSubOperationObject.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */

#include "skgobjectbase.h"

class SKGOperationObject;
class SKGCategoryObject;
class SKGRefundTrackerObject;

/**
 * This class manages suboperation object
 */
class KDE_EXPORT SKGSubOperationObject : public SKGObjectBase
{
        Q_OBJECT;

public:
        /**
         * Constructor
         * @param iDocument the document containing the object
         * @param iID the identifier in @p iTable of the object
         */
        explicit SKGSubOperationObject(const SKGDocument* iDocument=NULL, int iID=0);

        /**
         * Copy constructor
         * @param iObject the object to copy
         */
        SKGSubOperationObject(const SKGSubOperationObject& iObject);

        /**
         * Copy constructor
         * @param iObject the object to copy
         */
        SKGSubOperationObject(const SKGObjectBase& iObject);

        /**
         * Operator affectation
         * @param iObject the object to copy
         */
        virtual const SKGSubOperationObject& operator= (const SKGObjectBase &iObject);

        /**
         * Destructor
         */
        virtual ~SKGSubOperationObject();
        /**
         * Set the comment of suboperation
         * @param iComment the comment
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setComment(const QString& iComment);

        /**
         * Get the comment of this suboperation
         * @return the comment
         */
        virtual QString getComment() const;

        /**
         * Get the parent operation
         * @param oOperation the parent operation
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError getParentOperation(SKGOperationObject& oOperation) const;

        /**
         * Set the parent operation
         * @param iOperation the parent operation
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError setParentOperation(const SKGOperationObject& iOperation);

        /**
         * Set the category
         * @param iCategory the category
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setCategory(const SKGCategoryObject& iCategory);

        /**
         * Get the category
         * @param oCategory the category
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError getCategory(SKGCategoryObject& oCategory) const;

        /**
         * Set the refund tracker
         * @param iTracker the refund tracker
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setRefundTracker(const SKGRefundTrackerObject& iTracker);

        /**
         * Get the refund tracker
         * @param oTracker the refund tracker
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError getRefundTracker(SKGRefundTrackerObject& oTracker) const;

        /**
         * Remove the refund tracker
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError removeRefundTracker();

        /**
         * Set the quantity of the suboperation
         * @param iValue the value
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setQuantity(double iValue);

        /**
         * Get the quantity of the suboperation
         * @return the value
         */
        virtual double getQuantity() const;

};

#endif
